#
# Copyright (C) 2025 Indiscale GmbH <info@indiscale.com>
# Copyright (C) 2025 Florian Spreckelsen <f.spreckelsen@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
import linkahead as db

from caosadvancedtools.datainconsistency import DataInconsistencyError

from .utils import get_entity_name


def get_container(identifier: str) -> db.Record:
    """Return the container record for a given identifier string. By
    default, that's simply the id but may be overwritten for
    customization.

    """
    try:
        return db.cached.cached_get_entity_by(
            query=f"FIND '{get_entity_name('container_rt')}' WITH ID='{identifier}'"
        )
    except db.EmptyUniqueQueryError:
        try:
            return db.cached.cached_get_entity_by(
                query=f"FIND '{get_entity_name('container_rt')}' WITH name='{identifier}'"
            )
        except db.EmptyUniqueQueryError:
            raise DataInconsistencyError(
                f"Couldn't find a {get_entity_name('container_rt')} with name or id {identifier}."
            )
